about summary refs log tree commit diff
path: root/support/resolv_test.h
diff options
context:
space:
mode:
authorPaul Pluzhnikov <ppluzhnikov@google.com>2023-05-20 13:37:47 +0000
committerPaul Pluzhnikov <ppluzhnikov@google.com>2023-06-02 01:39:48 +0000
commit7f0d9e61f40c669fca3cfd1e342fa8236c7220b7 (patch)
treee02ce0ba813f2cb4f20643988ec030292784cab6 /support/resolv_test.h
parent5013f6fc6c44160e8ec6bcd34ba676e85d9d6ab6 (diff)
downloadglibc-7f0d9e61f40c669fca3cfd1e342fa8236c7220b7.tar.gz
glibc-7f0d9e61f40c669fca3cfd1e342fa8236c7220b7.tar.xz
glibc-7f0d9e61f40c669fca3cfd1e342fa8236c7220b7.zip
Fix all the remaining misspellings -- BZ 25337
Diffstat (limited to 'support/resolv_test.h')
-rw-r--r--support/resolv_test.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/support/resolv_test.h b/support/resolv_test.h
index 8d05fc4e06..32673f0213 100644
--- a/support/resolv_test.h
+++ b/support/resolv_test.h
@@ -116,7 +116,7 @@ struct resolv_redirect_config
   const struct sockaddr *const *server_address_overrides;
 };
 
 /* Configure NSS to use, nss_dns only for aplicable databases, and try
    to put the process into a network namespace for better isolation.
    This may have to be called before resolv_test_start, before the
    process creates any threads.  Otherwise, initialization is
@@ -125,7 +125,7 @@ void resolv_test_init (void);
 
 /* Initiate resolver testing.  This updates the _res variable as
    needed.  As a side effect, NSS is reconfigured to use nss_dns only
-   for aplicable databases, and the process may enter a network
+   for applicable databases, and the process may enter a network
    namespace for better isolation.  */
 struct resolv_test *resolv_test_start (struct resolv_redirect_config);
@@ -116,7 +116,7 @@ struct resolv_redirect_config
 };
 
-/* Configure NSS to use, nss_dns only for aplicable databases, and try
+/* Configure NSS to use, nss_dns only for applicable databases, and try
    to put the process into a network namespace for better isolation.
    This may have to be called before resolv_test_start, before the